@@ -18,8 +18,7 @@ import shutil
 from abc import ABC, abstractmethod
 from argparse import ArgumentParser, _ArgumentGroup
 from contextlib import contextmanager
-from typing import (cast,
-                    Any,
+from typing import (Any,
                     Callable,
                     ContextManager,
                     Dict,
@@ -28,14 +27,15 @@ from typing import (cast,
                     NamedTuple,
                     Optional,
                     TypeVar,
-                    Union)
+                    Union,
+                    cast)
 
 from toil.batchSystems.options import OptionSetter
 from toil.bus import MessageBus, MessageOutbox
 from toil.common import Config, Toil, cacheDirName
 from toil.deferred import DeferredFunctionManager
 from toil.fileStores.abstractFileStore import AbstractFileStore
-from toil.job import JobDescription, Requirer, ParsedRequirement
+from toil.job import JobDescription, ParsedRequirement, Requirer
 from toil.resource import Resource
 
 logger = logging.getLogger(__name__)
@@ -43,10 +43,10 @@ logger = logging.getLogger(__name__)
 # Value to use as exitStatus in UpdatedBatchJobInfo.exitStatus when status is not available.
 EXIT_STATUS_UNAVAILABLE_VALUE = 255
 
-class BatchJobExitReason(enum.Enum):
+class BatchJobExitReason(enum.IntEnum):
     FINISHED: int = 1  # Successfully finished.
     FAILED: int = 2  # Job finished, but failed.
-    LOST: int = 3  # Preemptable failure (job's executing host went away).
+    LOST: int = 3  # Preemptible failure (job's executing host went away).
     KILLED: int = 4  # Job killed before finishing.
     ERROR: int = 5  # Internal error.
     MEMLIMIT: int = 6  # Job hit batch system imposed memory limit
@@ -476,12 +476,12 @@ class AbstractScalableBatchSystem(AbstractBatchSystem):
     """
 
     @abstractmethod
-    def getNodes(self, preemptable: Optional[bool] = None, timeout: int = 600) -> Dict[str, NodeInfo]:
+    def getNodes(self, preemptible: Optional[bool] = None, timeout: int = 600) -> Dict[str, NodeInfo]:
         """
-        Returns a dictionary mapping node identifiers of preemptable or non-preemptable nodes to
+        Returns a dictionary mapping node identifiers of preemptible or non-preemptible nodes to
         NodeInfo objects, one for each node.
 
-        :param preemptable: If True (False) only (non-)preemptable nodes will be returned.
+        :param preemptible: If True (False) only (non-)preemptible nodes will be returned.
                If None, all nodes will be returned.
         """
         raise NotImplementedError()
