@@ -354,7 +354,7 @@ class LSFBatchSystem(AbstractGridEngineBatchSystem):
             :param jobID: ID number of the job
             """
             try:
-                output = subprocess.check_output(["bjobs", "-l", str(jobID)], universal_newlines=True)
+                output = subprocess.check_output(["bjobs", "-l", str(jobID)], text=True)
                 max_mem, command = parse_mem_and_cmd_from_output(output=output)
                 if not max_mem:
                     logger.warning(f"[job ID {jobID}] Unable to Collect Maximum Memory Usage: {output}")
