@@ -120,7 +120,7 @@ class MesosTestSupport:
             return [self.findMesosBinary(['mesos-agent']),
                     '--ip=127.0.0.1',
                     '--master=127.0.0.1:5050',
-                    '--attributes=preemptable:False',
+                    '--attributes=preemptible:False',
                     '--resources=cpus(*):%i' % self.numCores,
                     '--work_dir=/tmp/mesos',
                     '--no-systemd_enable_support']
