@@ -15,7 +15,7 @@ import logging
 import math
 import os
 from argparse import ArgumentParser, _ArgumentGroup
-from pipes import quote
+from shlex import quote
 from typing import Callable, Dict, List, Optional, TypeVar, Union
 
 from toil.batchSystems.abstractGridEngineBatchSystem import \
@@ -165,7 +165,7 @@ class SlurmBatchSystem(AbstractGridEngineBatchSystem):
                 if len(job_id_parts) > 1:
                     continue
                 job_id = int(job_id_parts[0])
-                status, signal = [int(n) for n in exitcode.split(':')]
+                status, signal = (int(n) for n in exitcode.split(':'))
                 if signal > 0:
                     # A non-zero signal may indicate e.g. an out-of-memory killed job
                     status = 128 + signal
@@ -238,7 +238,7 @@ class SlurmBatchSystem(AbstractGridEngineBatchSystem):
                 try:
                     exitcode = job['ExitCode']
                     if exitcode is not None:
-                        status, signal = [int(n) for n in exitcode.split(':')]
+                        status, signal = (int(n) for n in exitcode.split(':'))
                         if signal > 0:
                             # A non-zero signal may indicate e.g. an out-of-memory killed job
                             status = 128 + signal
@@ -272,6 +272,23 @@ class SlurmBatchSystem(AbstractGridEngineBatchSystem):
             if job_environment:
                 environment.update(job_environment)
 
+            # "Native extensions" for SLURM (see DRMAA or SAGA)
+            nativeConfig = os.getenv('TOIL_SLURM_ARGS')
+
+            # --export=[ALL,]<environment_toil_variables>
+            set_exports = "--export=ALL"
+
+            if nativeConfig is not None:
+                logger.debug("Native SLURM options appended to sbatch from TOIL_SLURM_ARGS env. variable: %s", nativeConfig)
+
+                for arg in nativeConfig.split():
+                    if arg.startswith("--mem") or arg.startswith("--cpus-per-task"):
+                        raise ValueError(f"Some resource arguments are incompatible: {nativeConfig}")
+                    # repleace default behaviour by the one stated at TOIL_SLURM_ARGS
+                    if arg.startswith("--export"):
+                        set_exports = arg
+                sbatch_line.extend(nativeConfig.split())
+
             if environment:
                 argList = []
 
@@ -279,7 +296,10 @@ class SlurmBatchSystem(AbstractGridEngineBatchSystem):
                     quoted_value = quote(os.environ[k] if v is None else v)
                     argList.append(f'{k}={quoted_value}')
 
-                sbatch_line.append('--export=' + ','.join(argList))
+                set_exports += ',' + ','.join(argList)
+
+            # add --export to the sbatch
+            sbatch_line.append(set_exports)
 
             parallel_env = os.getenv('TOIL_SLURM_PE')
             if cpu and cpu > 1 and parallel_env:
@@ -295,15 +315,6 @@ class SlurmBatchSystem(AbstractGridEngineBatchSystem):
             stderrfile: str = self.boss.formatStdOutErrPath(jobID, '%j', 'err')
             sbatch_line.extend(['-o', stdoutfile, '-e', stderrfile])
 
-            # "Native extensions" for SLURM (see DRMAA or SAGA)
-            nativeConfig = os.getenv('TOIL_SLURM_ARGS')
-            if nativeConfig is not None:
-                logger.debug("Native SLURM options appended to sbatch from TOIL_SLURM_ARGS env. variable: %s", nativeConfig)
-                if ("--mem" in nativeConfig) or ("--cpus-per-task" in nativeConfig):
-                    raise ValueError(f"Some resource arguments are incompatible: {nativeConfig}")
-
-                sbatch_line.extend(nativeConfig.split())
-
             return sbatch_line
 
         def parse_elapsed(self, elapsed):
