@@ -17,8 +17,8 @@ import os
 import shlex
 import tempfile
 import time
-from pipes import quote
 from queue import Empty
+from shlex import quote
 from typing import Dict, List, Optional
 
 from toil.batchSystems.abstractGridEngineBatchSystem import (AbstractGridEngineBatchSystem,
