@@ -67,6 +67,16 @@ class FileJobStore(AbstractJobStore):
     # 10Mb RAM chunks when reading/writing files
     BUFFER_SIZE = 10485760  # 10Mb
 
+    def default_caching(self) -> bool:
+        """
+        Jobstore's preference as to whether it likes caching or doesn't care about it.
+        Some jobstores benefit from caching, however on some local configurations it can be flaky.
+
+        see https://github.com/DataBiosphere/toil/issues/4218
+        """
+
+        return False
+
     def __init__(self, path: str, fanOut: int = 1000) -> None:
         """
         :param path: Path to directory holding the job store
@@ -650,8 +660,7 @@ class FileJobStore(AbstractJobStore):
         else:
             with open(
                 self._get_file_path_from_id(file_id),
-                "rt",
-                1,
+                buffering=1,  # line buffering
                 encoding=encoding,
                 errors=errors,
             ) as ft:
