@@ -132,18 +132,17 @@ import time
 import traceback
 import urllib.error
 from contextlib import contextmanager
-from typing import (
-    Any,
-    Callable,
-    ContextManager,
-    Generator,
-    Iterable,
-    List,
-    Optional,
-    Sequence,
-    Tuple,
-    Union,
-)
+from typing import (Any,
+                    Callable,
+                    ContextManager,
+                    Generator,
+                    Iterable,
+                    List,
+                    Optional,
+                    Sequence,
+                    Tuple,
+                    Type,
+                    Union)
 
 import requests.exceptions
 import urllib3.exceptions
@@ -228,7 +227,7 @@ class ErrorCondition:
 def retry(
     intervals: Optional[List] = None,
     infinite_retries: bool = False,
-    errors: Optional[Sequence[Union[ErrorCondition, Exception, Any]]] = None,
+    errors: Optional[Sequence[Union[ErrorCondition, Type[Exception]]]] = None,
     log_message: Optional[Tuple[Callable, str]] = None,
     prepare: Optional[List[Callable]] = None,
 ) -> Callable[[Any], Any]:
