@@ -17,16 +17,15 @@ import os
 from collections import namedtuple
 from operator import attrgetter
 from statistics import mean, stdev
-from typing import List, Optional, Any
+from typing import Any, List, Optional
 
-from toil.lib.aws import (get_aws_zone_from_environment,
-                          get_aws_zone_from_metadata,
+from toil.lib.aws import (get_aws_zone_from_boto,
+                          get_aws_zone_from_environment,
                           get_aws_zone_from_environment_region,
-                          get_aws_zone_from_boto,
+                          get_aws_zone_from_metadata,
                           running_on_ec2,
                           zone_to_region)
 
-
 logger = logging.getLogger(__name__)
 
 ZoneTuple = namedtuple('ZoneTuple', ['name', 'price_deviation'])
