@@ -68,6 +68,7 @@ from toil.lib.misc import truncExpBackoff
 from toil.lib.retry import (ErrorCondition,
                             get_error_body,
                             get_error_code,
+                            get_error_message,
                             get_error_status,
                             old_retry,
                             retry)
@@ -116,7 +117,15 @@ def awsRetryPredicate(e):
     return False
 
 
-def expectedShutdownErrors(e):
+def expectedShutdownErrors(e: Exception) -> bool:
+    """
+    Matches errors that we expect to occur during shutdown, and which indicate
+    that we need to wait or try again.
+
+    Should *not* match any errors which indicate that an operation is
+    impossible or unnecessary (such as errors resulting from a thing not
+    existing to be deleted).
+    """
     return get_error_status(e) == 400 and 'dependent object' in get_error_body(e)
 
 
@@ -249,7 +258,7 @@ class AWSProvisioner(AbstractProvisioner):
             s3_client.head_bucket(Bucket=bucket_name)
             bucket = s3.Bucket(bucket_name)
         except ClientError as err:
-            if err.response.get('ResponseMetadata', {}).get('HTTPStatusCode') == 404:
+            if get_error_status(err) == 404:
                 bucket = create_s3_bucket(s3, bucket_name=bucket_name, region=self._region)
                 bucket.wait_until_exists()
                 bucket.Versioning().enable()
@@ -276,7 +285,7 @@ class AWSProvisioner(AbstractProvisioner):
         try:
             return obj.get().get('Body').read()
         except ClientError as e:
-            if e.response.get('ResponseMetadata', {}).get('HTTPStatusCode') == 404:
+            if get_error_status(e) == 404:
                 logger.warning(f'Trying to read non-existent file "{key}" from {bucket_name}.')
             raise
 
@@ -293,7 +302,8 @@ class AWSProvisioner(AbstractProvisioner):
                       userTags: Optional[dict],
                       vpcSubnet: Optional[str],
                       awsEc2ProfileArn: Optional[str],
-                      awsEc2ExtraSecurityGroupIds: Optional[list]):
+                      awsEc2ExtraSecurityGroupIds: Optional[list],
+                      **kwargs):
         """
         Starts a single leader node and populates this class with the leader's metadata.
 
@@ -309,6 +319,9 @@ class AWSProvisioner(AbstractProvisioner):
         :return: None
         """
 
+        if 'network' in kwargs:
+            logger.warning('AWS provisioner does not support a network parameter. Ignoring %s!', kwargs["network"])
+
         # First, pre-flight-check our permissions before making anything.
         if not policy_permissions_allow(get_policy_permissions(region=self._region), CLUSTER_LAUNCHING_PERMISSIONS):
             # Function prints a more specific warning to the log, but give some context.
@@ -405,7 +418,7 @@ class AWSProvisioner(AbstractProvisioner):
 
         leaderNode = Node(publicIP=leader.public_ip_address, privateIP=leader.private_ip_address,
                           name=leader.id, launchTime=leader.launch_time,
-                          nodeType=leader_type.name, preemptable=False,
+                          nodeType=leader_type.name, preemptible=False,
                           tags=leader.tags)
         leaderNode.waitForNode('toil_leader')
 
@@ -567,7 +580,7 @@ class AWSProvisioner(AbstractProvisioner):
 
         return 'aws'
 
-    def getNodeShape(self, instance_type: str, preemptable=False) -> Shape:
+    def getNodeShape(self, instance_type: str, preemptible=False) -> Shape:
         """
         Get the Shape for the given instance type (e.g. 't2.medium').
         """
@@ -587,7 +600,7 @@ class AWSProvisioner(AbstractProvisioner):
                      memory=memory,
                      cores=type_info.cores,
                      disk=disk,
-                     preemptable=preemptable)
+                     preemptible=preemptible)
 
     @staticmethod
     def retryPredicate(e):
@@ -611,12 +624,21 @@ class AWSProvisioner(AbstractProvisioner):
 
         logger.debug('Deleting autoscaling groups ...')
         removed = False
+
         for attempt in old_retry(timeout=300, predicate=expectedShutdownErrors):
             with attempt:
                 for asgName in self._getAutoScalingGroupNames():
-                    # We delete the group and all the instances via ForceDelete.
-                    self.aws.client(self._region, 'autoscaling').delete_auto_scaling_group(AutoScalingGroupName=asgName, ForceDelete=True)
-                    removed = True
+                    try:
+                        # We delete the group and all the instances via ForceDelete.
+                        self.aws.client(self._region, 'autoscaling').delete_auto_scaling_group(AutoScalingGroupName=asgName, ForceDelete=True)
+                        removed = True
+                    except ClientError as e:
+                        if get_error_code(e) == 'ValidationError' and 'AutoScalingGroup name not found' in get_error_message(e):
+                            # This ASG does not need to be removed (or a
+                            # previous delete returned an error but also
+                            # succeeded).
+                            pass
+
         if removed:
             logger.debug('... Successfully deleted autoscaling groups')
 
@@ -705,7 +727,7 @@ class AWSProvisioner(AbstractProvisioner):
                 except s3.meta.client.exceptions.NoSuchBucket:
                     pass
                 except ClientError as e:
-                    if e.response.get('ResponseMetadata', {}).get('HTTPStatusCode') == 404:
+                    if get_error_status(e) == 404:
                         pass
                     else:
                         raise  # retry this
@@ -743,19 +765,19 @@ class AWSProvisioner(AbstractProvisioner):
                         break
                 if spot_bid is None:
                     # We didn't bid on any class including this type either
-                    raise RuntimeError("No spot bid given for a preemptable node request.")
+                    raise RuntimeError("No spot bid given for a preemptible node request.")
             else:
-                raise RuntimeError("No spot bid given for a preemptable node request.")
+                raise RuntimeError("No spot bid given for a preemptible node request.")
 
         return spot_bid
 
-    def addNodes(self, nodeTypes: Set[str], numNodes, preemptable, spotBid=None) -> int:
+    def addNodes(self, nodeTypes: Set[str], numNodes, preemptible, spotBid=None) -> int:
         # Grab the AWS connection we need
         ec2 = self.aws.boto2(self._region, 'ec2')
 
         assert self._leaderPrivateIP
 
-        if preemptable:
+        if preemptible:
             # May need to provide a spot bid
             spotBid = self._recover_node_type_bid(nodeTypes, spotBid)
 
@@ -768,8 +790,8 @@ class AWSProvisioner(AbstractProvisioner):
                                                rootVolSize=root_vol_size)
 
         # Pick a zone and subnet_id to launch into
-        if preemptable:
-            # We may need to balance preemptable instances across zones, which
+        if preemptible:
+            # We may need to balance preemptible instances across zones, which
             # then affects the subnets they can use.
 
             # We're allowed to pick from any of these zones.
@@ -794,7 +816,7 @@ class AWSProvisioner(AbstractProvisioner):
             subnet_id = next(iter(self._worker_subnets_by_zone[zone]))
 
         keyPath = self._sseKey if self._sseKey else None
-        userData = self._getIgnitionUserData('worker', keyPath, preemptable, self._architecture)
+        userData = self._getIgnitionUserData('worker', keyPath, preemptible, self._architecture)
         if isinstance(userData, str):
             # Spot-market provisioning requires bytes for user data.
             userData = userData.encode('utf-8')
@@ -815,13 +837,13 @@ class AWSProvisioner(AbstractProvisioner):
                 # after we start launching instances we want to ensure the full setup is done
                 # the biggest obstacle is AWS request throttling, so we retry on these errors at
                 # every request in this method
-                if not preemptable:
-                    logger.debug('Launching %s non-preemptable nodes', numNodes)
+                if not preemptible:
+                    logger.debug('Launching %s non-preemptible nodes', numNodes)
                     instancesLaunched = create_ondemand_instances(ec2,
                                                                   image_id=self._discoverAMI(),
                                                                   spec=kwargs, num_instances=numNodes)
                 else:
-                    logger.debug('Launching %s preemptable nodes', numNodes)
+                    logger.debug('Launching %s preemptible nodes', numNodes)
                     # force generator to evaluate
                     instancesLaunched = list(create_spot_instances(ec2=ec2,
                                                                    price=spotBid,
@@ -844,21 +866,21 @@ class AWSProvisioner(AbstractProvisioner):
             for i in instancesLaunched:
                 self._waitForIP(i)
                 node = Node(publicIP=i.ip_address, privateIP=i.private_ip_address, name=i.id,
-                            launchTime=i.launch_time, nodeType=i.instance_type, preemptable=preemptable,
+                            launchTime=i.launch_time, nodeType=i.instance_type, preemptible=preemptible,
                             tags=i.tags)
                 node.waitForNode('toil_worker')
                 node.coreRsync([self._sseKey, ':' + self._sseKey], applianceName='toil_worker')
         logger.debug('Launched %s new instance(s)', numNodes)
         return len(instancesLaunched)
 
-    def addManagedNodes(self, nodeTypes: Set[str], minNodes, maxNodes, preemptable, spotBid=None) -> None:
+    def addManagedNodes(self, nodeTypes: Set[str], minNodes, maxNodes, preemptible, spotBid=None) -> None:
 
         if self.clusterType != 'kubernetes':
             raise ManagedNodesNotSupportedException("Managed nodes only supported for Kubernetes clusters")
 
         assert self._leaderPrivateIP
 
-        if preemptable:
+        if preemptible:
             # May need to provide a spot bid
             spotBid = self._recover_node_type_bid(nodeTypes, spotBid)
 
@@ -866,24 +888,24 @@ class AWSProvisioner(AbstractProvisioner):
 
         # Make one template per node type, so we can apply storage overrides correctly
         # TODO: deduplicate these if the same instance type appears in multiple sets?
-        launch_template_ids = {n: self._get_worker_launch_template(n, preemptable=preemptable) for n in nodeTypes}
+        launch_template_ids = {n: self._get_worker_launch_template(n, preemptible=preemptible) for n in nodeTypes}
         # Make the ASG across all of them
         self._createWorkerAutoScalingGroup(launch_template_ids, nodeTypes, minNodes, maxNodes,
                                            spot_bid=spotBid)
 
-    def getProvisionedWorkers(self, instance_type: Optional[str] = None, preemptable: Optional[bool] = None) -> List[Node]:
+    def getProvisionedWorkers(self, instance_type: Optional[str] = None, preemptible: Optional[bool] = None) -> List[Node]:
         assert self._leaderPrivateIP
         entireCluster = self._get_nodes_in_cluster(instance_type=instance_type)
         logger.debug('All nodes in cluster: %s', entireCluster)
         workerInstances = [i for i in entireCluster if i.private_ip_address != self._leaderPrivateIP]
         logger.debug('All workers found in cluster: %s', workerInstances)
-        if preemptable is not None:
-            workerInstances = [i for i in workerInstances if preemptable == (i.spot_instance_request_id is not None)]
-            logger.debug('%spreemptable workers found in cluster: %s', 'non-' if not preemptable else '', workerInstances)
+        if preemptible is not None:
+            workerInstances = [i for i in workerInstances if preemptible == (i.spot_instance_request_id is not None)]
+            logger.debug('%spreemptible workers found in cluster: %s', 'non-' if not preemptible else '', workerInstances)
         workerInstances = awsFilterImpairedNodes(workerInstances, self.aws.boto2(self._region, 'ec2'))
         return [Node(publicIP=i.ip_address, privateIP=i.private_ip_address,
                      name=i.id, launchTime=i.launch_time, nodeType=i.instance_type,
-                     preemptable=i.spot_instance_request_id is not None, tags=i.tags)
+                     preemptible=i.spot_instance_request_id is not None, tags=i.tags)
                 for i in workerInstances]
 
     @memoize
@@ -951,7 +973,7 @@ class AWSProvisioner(AbstractProvisioner):
 
         leaderNode = Node(publicIP=leader.ip_address, privateIP=leader.private_ip_address,
                           name=leader.id, launchTime=leader.launch_time, nodeType=None,
-                          preemptable=False, tags=leader.tags)
+                          preemptible=False, tags=leader.tags)
         if wait:
             logger.debug("Waiting for toil_leader to enter 'running' state...")
             wait_instances_running(self.aws.boto2(self._region, 'ec2'), [leader])
@@ -1056,7 +1078,7 @@ class AWSProvisioner(AbstractProvisioner):
         # Disk count is weirdly a float in our instance database, so make it an int here.
         for disk in range(1, int(type_info.disks) + 1):
             bdm[bdtKeys[disk]] = Boto2BlockDeviceType(
-                ephemeral_name='ephemeral{}'.format(disk - 1))  # ephemeral counts start at 0
+                ephemeral_name=f'ephemeral{disk - 1}')  # ephemeral counts start at 0
 
         logger.debug('Device mapping: %s', bdm)
         return bdm
@@ -1087,7 +1109,7 @@ class AWSProvisioner(AbstractProvisioner):
             # virtual block device in the VM
             bdms.append({
                 'DeviceName': bdtKeys[disk],
-                'VirtualName': 'ephemeral{}'.format(disk - 1)  # ephemeral counts start at 0
+                'VirtualName': f'ephemeral{disk - 1}'  # ephemeral counts start at 0
             })
         logger.debug('Device mapping: %s', bdms)
         return bdms
@@ -1110,14 +1132,14 @@ class AWSProvisioner(AbstractProvisioner):
 
         return [i for i in all_instances if instanceFilter(i)]
 
-    def _filter_nodes_in_cluster(self, instance_type: Optional[str] = None, preemptable: bool = False) -> List[Boto2Instance]:
+    def _filter_nodes_in_cluster(self, instance_type: Optional[str] = None, preemptible: bool = False) -> List[Boto2Instance]:
         """
         Get Boto2 instance objects for the nodes in the cluster filtered by preemptability.
         """
 
         instances = self._get_nodes_in_cluster(instance_type, include_stopped_nodes=False)
 
-        if preemptable:
+        if preemptible:
             return [i for i in instances if i.spot_instance_request_id is not None]
 
         return [i for i in instances if i.spot_instance_request_id is None]
@@ -1236,7 +1258,7 @@ class AWSProvisioner(AbstractProvisioner):
         return allTemplateIDs
 
     @awsRetry
-    def _get_worker_launch_template(self, instance_type: str, preemptable: bool = False, backoff: float = 1.0) -> str:
+    def _get_worker_launch_template(self, instance_type: str, preemptible: bool = False, backoff: float = 1.0) -> str:
         """
         Get a launch template for instances with the given parameters. Only one
         such launch template will be created, no matter how many times the
@@ -1247,7 +1269,7 @@ class AWSProvisioner(AbstractProvisioner):
         :param instance_type: Type of node to use in the template. May be overridden
                               by an ASG that uses the template.
 
-        :param preemptable: When the node comes up, does it think it is a spot instance?
+        :param preemptible: When the node comes up, does it think it is a spot instance?
 
         :param backoff: How long to wait if it seems like we aren't reading our
                         own writes before trying again.
@@ -1255,7 +1277,7 @@ class AWSProvisioner(AbstractProvisioner):
         :return: The ID of the template.
         """
 
-        lt_name = self._name_worker_launch_template(instance_type, preemptable=preemptable)
+        lt_name = self._name_worker_launch_template(instance_type, preemptible=preemptible)
 
         # How do we match the right templates?
         filters = [{'Name': 'launch-template-name', 'Values': [lt_name]}]
@@ -1270,45 +1292,45 @@ class AWSProvisioner(AbstractProvisioner):
         elif len(templates) == 0:
             # Template doesn't exist so we can create it.
             try:
-                return self._create_worker_launch_template(instance_type, preemptable=preemptable)
+                return self._create_worker_launch_template(instance_type, preemptible=preemptible)
             except ClientError as e:
                 if get_error_code(e) == 'InvalidLaunchTemplateName.AlreadyExistsException':
                     # Someone got to it before us (or we couldn't read our own
                     # writes). Recurse to try again, because now it exists.
                     logger.info('Waiting %f seconds for template %s to be available', backoff, lt_name)
                     time.sleep(backoff)
-                    return self._get_worker_launch_template(instance_type, preemptable=preemptable, backoff=backoff*2)
+                    return self._get_worker_launch_template(instance_type, preemptible=preemptible, backoff=backoff*2)
                 else:
                     raise
         else:
             # There must be exactly one template
             return templates[0]
 
-    def _name_worker_launch_template(self, instance_type: str, preemptable: bool = False) -> str:
+    def _name_worker_launch_template(self, instance_type: str, preemptible: bool = False) -> str:
         """
         Get the name we should use for the launch template with the given parameters.
 
         :param instance_type: Type of node to use in the template. May be overridden
                               by an ASG that uses the template.
 
-        :param preemptable: When the node comes up, does it think it is a spot instance?
+        :param preemptible: When the node comes up, does it think it is a spot instance?
         """
 
         # The name has the cluster name in it
         lt_name = f'{self.clusterName}-lt-{instance_type}'
-        if preemptable:
+        if preemptible:
             lt_name += '-spot'
 
         return lt_name
 
-    def _create_worker_launch_template(self, instance_type: str, preemptable: bool = False) -> str:
+    def _create_worker_launch_template(self, instance_type: str, preemptible: bool = False) -> str:
         """
         Create the launch template for launching worker instances for the cluster.
 
         :param instance_type: Type of node to use in the template. May be overridden
                               by an ASG that uses the template.
 
-        :param preemptable: When the node comes up, does it think it is a spot instance?
+        :param preemptible: When the node comes up, does it think it is a spot instance?
 
         :return: The ID of the template created.
         """
@@ -1321,9 +1343,9 @@ class AWSProvisioner(AbstractProvisioner):
         bdms = self._getBoto3BlockDeviceMappings(type_info, rootVolSize=rootVolSize)
 
         keyPath = self._sseKey if self._sseKey else None
-        userData = self._getIgnitionUserData('worker', keyPath, preemptable, self._architecture)
+        userData = self._getIgnitionUserData('worker', keyPath, preemptible, self._architecture)
 
-        lt_name = self._name_worker_launch_template(instance_type, preemptable=preemptable)
+        lt_name = self._name_worker_launch_template(instance_type, preemptible=preemptible)
 
         # But really we find it by tag
         tags = dict(self._tags)
