@@ -29,14 +29,17 @@ logger = logging.getLogger(__name__)
 class Node:
     maxWaitTime = 7 * 60
 
-    def __init__(self, publicIP, privateIP, name, launchTime, nodeType, preemptable, tags=None):
+    def __init__(self, publicIP, privateIP, name, launchTime, nodeType, preemptible, tags=None, use_private_ip=None):
         self.publicIP = publicIP
         self.privateIP = privateIP
-        self.effectiveIP = self.publicIP or self.privateIP
+        if use_private_ip:
+            self.effectiveIP = self.privateIP #or self.publicIP?
+        else:
+            self.effectiveIP = self.publicIP or self.privateIP
         self.name = name
         self.launchTime = launchTime
         self.nodeType = nodeType
-        self.preemptable = preemptable
+        self.preemptible = preemptible
         self.tags = tags
 
     def __str__(self):
@@ -252,7 +255,7 @@ class Node:
             commandTokens.extend(sshOptions)
         # specify host
         user = kwargs.pop('user', 'core')  # CHANGED: Is this needed?
-        commandTokens.append('{}@{}'.format(user, str(self.effectiveIP)))
+        commandTokens.append(f'{user}@{str(self.effectiveIP)}')
 
         inputString = kwargs.pop('input', None)
         if inputString is not None:
