@@ -14,16 +14,15 @@
 import argparse
 import logging
 import os
-
 from typing import Type
 
 import connexion  # type: ignore
 
+from toil.lib.aws import get_current_aws_region, running_on_ec2, running_on_ecs
 from toil.lib.misc import get_public_ip
 from toil.server.wes.toil_backend import ToilBackend
 from toil.server.wsgi_app import run_app
 from toil.version import version
-from toil.lib.aws import running_on_ec2, running_on_ecs, get_current_aws_region
 
 logger = logging.getLogger(__name__)
 
@@ -31,9 +30,10 @@ logger = logging.getLogger(__name__)
 def parser_with_server_options() -> argparse.ArgumentParser:
     parser = argparse.ArgumentParser(description="Toil server mode.")
 
-    parser.add_argument("--debug", action="store_true", default=False)
+    parser.add_argument("--debug", action="store_true", default=False,
+                        help="Enable debug mode.")
     parser.add_argument("--bypass_celery", action="store_true", default=False,
-                        help="Skip sending workflows to Celery and just run them under the"
+                        help="Skip sending workflows to Celery and just run them under the "
                              "server. For testing.")
     parser.add_argument("--host", type=str, default="127.0.0.1",
                         help="The host interface that the Toil server binds on. (default: '127.0.0.1').")
@@ -68,6 +68,10 @@ def parser_with_server_options() -> argparse.ArgumentParser:
     parser.add_argument("--dest_bucket_base", type=str, default=None,
                         help="Direct CWL workflows to save output files to dynamically generated "
                              "unique paths under the given URL. Supports AWS S3.")
+    parser.add_argument("--wes_dialect", type=str, default="standard", choices=["standard", "agc"],
+                        help="Restrict WES responses to a dialect compatible with clients that do not fully "
+                             "implement the WES standard. (default: 'standard')")
+
     parser.add_argument("--version", action='version', version=version)
     return parser
 
@@ -92,7 +96,8 @@ def create_app(args: argparse.Namespace) -> "connexion.FlaskApp":
                           state_store=args.state_store,
                           options=args.opt,
                           dest_bucket_base=args.dest_bucket_base,
-                          bypass_celery=args.bypass_celery)
+                          bypass_celery=args.bypass_celery,
+                          wes_dialect=args.wes_dialect)
 
     flask_app.add_api('workflow_execution_service.swagger.yaml',
                       resolver=connexion.Resolver(backend.resolve_operation_id))  # noqa
@@ -107,7 +112,7 @@ def create_app(args: argparse.Namespace) -> "connexion.FlaskApp":
         flask_app.app.add_url_rule("/engine/v1/status", view_func=backend.get_health)
         # And we can provide lost humans some information on what they are looking at
         flask_app.app.add_url_rule("/", view_func=backend.get_homepage)
-        
+
     return flask_app
 
 
