@@ -19,7 +19,7 @@ import time
 from argparse import ArgumentParser, Namespace
 from logging.handlers import RotatingFileHandler
 from threading import Event, Thread
-from typing import TYPE_CHECKING, Any, Callable, IO, List, Optional, Union
+from typing import IO, TYPE_CHECKING, Any, Callable, List, Optional, Union
 
 from toil.lib.expando import Expando
 from toil.lib.resources import get_total_cpu_time
