@@ -1,4 +1,5 @@
 import os
+import tempfile
 
 from toil.common import Toil
 from toil.job import Job
@@ -10,7 +11,9 @@ align = Job.wrapJobFn(apiDockerCall,
                       parameters=['ls', '-lha'])
 
 if __name__ == "__main__":
-    options = Job.Runner.getDefaultOptions("./toilWorkflowRun")
+    jobstore: str = tempfile.mkdtemp("tutorial_docker")
+    os.rmdir(jobstore)
+    options = Job.Runner.getDefaultOptions(jobstore)
     options.logLevel = "INFO"
     options.clean = "always"
 
