@@ -1,4 +1,5 @@
 import os
+import tempfile
 
 from toil.common import Toil
 from toil.job import Job
@@ -43,7 +44,9 @@ def globalFileStoreJobFn(job):
 
 
 if __name__ == "__main__":
-    options = Job.Runner.getDefaultOptions("./toilWorkflowRun")
+    jobstore: str = tempfile.mkdtemp("tutorial_managing2")
+    os.rmdir(jobstore)
+    options = Job.Runner.getDefaultOptions(jobstore)
     options.logLevel = "INFO"
     options.clean = "always"
 
