@@ -1,4 +1,5 @@
 import os
+import tempfile
 
 from toil.common import Toil
 from toil.job import Job
@@ -17,7 +18,9 @@ class HelloWorld(Job):
 
 
 if __name__ == "__main__":
-    options = Job.Runner.getDefaultOptions("./toilWorkflowRun")
+    jobstore: str = tempfile.mkdtemp("tutorial_staging")
+    os.rmdir(jobstore)
+    options = Job.Runner.getDefaultOptions(jobstore)
     options.logLevel = "INFO"
     options.clean = "always"
 
