@@ -1,10 +1,12 @@
 import os
 import subprocess
+import tempfile
 
 from toil.common import Toil
 from toil.job import Job
 
 
+
 def initialize_jobs(job):
     job.fileStore.logToMaster("initialize_jobs")
 
@@ -25,7 +27,9 @@ def runQC(job, wdl_file, wdl_filename, json_file, json_filename, outputs_dir, ja
 
 
 if __name__ == "__main__":
-    options = Job.Runner.getDefaultOptions("./toilWorkflowRun")
+    jobstore: str = tempfile.mkdtemp("tutorial_wdlexample")
+    os.rmdir(jobstore)
+    options = Job.Runner.getDefaultOptions(jobstore)
     options.logLevel = "INFO"
     options.clean = "always"
 
