@@ -81,7 +81,7 @@ class AbstractJobStoreTest:
     class Test(ToilTest, metaclass=ABCMeta):
         @classmethod
         def setUpClass(cls):
-            super(AbstractJobStoreTest.Test, cls).setUpClass()
+            super().setUpClass()
             logging.basicConfig(level=logging.DEBUG)
             logging.getLogger('boto').setLevel(logging.CRITICAL)
             logging.getLogger('boto').setLevel(logging.WARNING)
@@ -99,7 +99,7 @@ class AbstractJobStoreTest:
         @classmethod
         @memoize
         def __new__(cls, *args):
-            return super(AbstractJobStoreTest.Test, cls).__new__(cls)
+            return super().__new__(cls)
 
         def _createConfig(self):
             return Config()
@@ -112,7 +112,7 @@ class AbstractJobStoreTest:
             raise NotImplementedError()
 
         def setUp(self):
-            super(AbstractJobStoreTest.Test, self).setUp()
+            super().setUp()
             self.namePrefix = 'jobstore-test-' + str(uuid.uuid4())
             self.config = self._createConfig()
 
@@ -127,20 +127,20 @@ class AbstractJobStoreTest:
             self.jobstore_resumed_noconfig.resume()
 
             # Requirements for jobs to be created.
-            self.arbitraryRequirements = {'memory': 1, 'disk': 2, 'cores': 1, 'preemptable': False}
+            self.arbitraryRequirements = {'memory': 1, 'disk': 2, 'cores': 1, 'preemptible': False}
             # Function to make an arbitrary new job
             self.arbitraryJob = lambda: JobDescription(command='command',
                                                        jobName='arbitrary',
                                                        requirements=self.arbitraryRequirements)
 
-            self.parentJobReqs = dict(memory=12, cores=34, disk=35, preemptable=True)
-            self.childJobReqs1 = dict(memory=23, cores=45, disk=46, preemptable=True)
-            self.childJobReqs2 = dict(memory=34, cores=56, disk=57, preemptable=False)
+            self.parentJobReqs = dict(memory=12, cores=34, disk=35, preemptible=True)
+            self.childJobReqs1 = dict(memory=23, cores=45, disk=46, preemptible=True)
+            self.childJobReqs2 = dict(memory=34, cores=56, disk=57, preemptible=False)
 
         def tearDown(self):
             self.jobstore_initialized.destroy()
             self.jobstore_resumed_noconfig.destroy()
-            super(AbstractJobStoreTest.Test, self).tearDown()
+            super().tearDown()
 
         def testInitialState(self):
             """Ensure proper handling of nonexistant files."""
@@ -173,7 +173,7 @@ class AbstractJobStoreTest:
             self.assertEqual(job.memory, self.parentJobReqs['memory'])
             self.assertEqual(job.cores, self.parentJobReqs['cores'])
             self.assertEqual(job.disk, self.parentJobReqs['disk'])
-            self.assertEqual(job.preemptable, self.parentJobReqs['preemptable'])
+            self.assertEqual(job.preemptible, self.parentJobReqs['preemptible'])
             self.assertEqual(job.jobName, 'test1')
             self.assertEqual(job.unitName, 'onParent')
 
@@ -556,7 +556,7 @@ class AbstractJobStoreTest:
         def testBatchCreate(self):
             """Test creation of many jobs."""
             jobstore = self.jobstore_initialized
-            jobRequirements = dict(memory=12, cores=34, disk=35, preemptable=True)
+            jobRequirements = dict(memory=12, cores=34, disk=35, preemptible=True)
             jobs = []
             with jobstore.batch():
                 for i in range(100):
@@ -1073,14 +1073,14 @@ class AbstractEncryptedJobStoreTest:
         def setUp(self):
             # noinspection PyAttributeOutsideInit
             self.sseKeyDir = tempfile.mkdtemp()
-            super(AbstractEncryptedJobStoreTest.Test, self).setUp()
+            super().setUp()
 
         def tearDown(self):
-            super(AbstractEncryptedJobStoreTest.Test, self).tearDown()
+            super().tearDown()
             shutil.rmtree(self.sseKeyDir)
 
         def _createConfig(self):
-            config = super(AbstractEncryptedJobStoreTest.Test, self)._createConfig()
+            config = super()._createConfig()
             sseKeyFile = os.path.join(self.sseKeyDir, 'keyFile')
             with open(sseKeyFile, 'w') as f:
                 f.write('01234567890123456789012345678901')
@@ -1361,7 +1361,7 @@ class AWSJobStoreTest(AbstractJobStoreTest.Test):
 
     def testOverlargeJob(self):
         jobstore = self.jobstore_initialized
-        jobRequirements = dict(memory=12, cores=34, disk=35, preemptable=True)
+        jobRequirements = dict(memory=12, cores=34, disk=35, preemptible=True)
         overlargeJob = JobDescription(command='overlarge',
                                       requirements=jobRequirements,
                                       jobName='test-overlarge', unitName='onJobStore')
