@@ -18,10 +18,10 @@ from toil.test import ToilTest
 
 
 class DataStructuresTest(ToilTest):
-    def _getJob(self, cores=1, memory=1000, disk=5000, preemptable=True):
+    def _getJob(self, cores=1, memory=1000, disk=5000, preemptible=True):
         from toil.batchSystems.mesos import MesosShape, ToilJob
 
-        resources = MesosShape(wallTime=0, cores=cores, memory=memory, disk=disk, preemptable=preemptable)
+        resources = MesosShape(wallTime=0, cores=cores, memory=memory, disk=disk, preemptible=preemptible)
 
         job = ToilJob(jobID=str(uuid.uuid4()),
                       name=str(uuid.uuid4()),
@@ -42,22 +42,22 @@ class DataStructuresTest(ToilTest):
         jobQueue = JobQueue()
 
         for jobNum in range(0, testJobs):
-            testJob = self._getJob(cores=random.choice(list(range(10))), preemptable=random.choice([True, False]))
+            testJob = self._getJob(cores=random.choice(list(range(10))), preemptible=random.choice([True, False]))
             jobQueue.insertJob(testJob, testJob.resources)
 
         sortedTypes = jobQueue.sortedTypes
         self.assertGreaterEqual(20, len(sortedTypes))
         self.assertTrue(all(sortedTypes[i] <= sortedTypes[i + 1] for i in range(len(sortedTypes) - 1)))
 
-        preemptable = sortedTypes.pop(0).preemptable
+        preemptible = sortedTypes.pop(0).preemptible
         for jtype in sortedTypes:
-            # all non preemptable jobTypes must be first in sorted order
-            if preemptable:
-                # all the rest of the jobTypes must be preemptable as well
-                assert jtype.preemptable
-            elif jtype.preemptable:
-                # we have reached our first preemptable job
-                preemptable = jtype.preemptable
+            # all non preemptible jobTypes must be first in sorted order
+            if preemptible:
+                # all the rest of the jobTypes must be preemptible as well
+                assert jtype.preemptible
+            elif jtype.preemptible:
+                # we have reached our first preemptible job
+                preemptible = jtype.preemptible
 
         # make sure proper number of jobs are in queue
         self.assertEqual(len(jobQueue.jobIDs()), testJobs)
