@@ -16,12 +16,10 @@ import logging
 
 from toil.job import Job
 from toil.realtimeLogger import RealtimeLogger
-from toil.test import ToilTest, travis_test
+from toil.test import ToilTest
 
 
 class RealtimeLoggerTest(ToilTest):
-
-    @travis_test
     def testRealtimeLogger(self):
         options = Job.Runner.getDefaultOptions(self._getTestJobStorePath())
         options.realTimeLogging = True
@@ -48,7 +46,7 @@ class MessageDetector(logging.StreamHandler):
     def __init__(self):
         self.detected = False  # Have we seen the message we want?
         self.overLogged = False  # Have we seen the message we don't want?
-        super(MessageDetector, self).__init__()
+        super().__init__()
 
     def emit(self, record):
         if record.msg == 'This should be logged at info level':
