@@ -1,4 +1,4 @@
-# Copyright (C) 2017 Regents of the University of California
+# Copyright (C) 2015-2021 Regents of the University of California
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,6 +17,7 @@
 collect_ignore = []
 
 try:
-    import toil.wdl.wdl_parser
+    import wdlparse
+    print(wdlparse.__file__)  # keep this import from being removed
 except ImportError:
     collect_ignore.append("toilwdl.py")
