@@ -107,8 +107,8 @@ def nextChainable(predecessor: JobDescription, jobStore: AbstractJobStore, confi
     if successor.disk > predecessor.disk:
         logger.debug("We need more disk for the next job, so finishing")
         return None
-    if successor.preemptable != predecessor.preemptable:
-        logger.debug("Preemptability is different for the next job, returning to the leader")
+    if successor.preemptible != predecessor.preemptible:
+        logger.debug("Preemptibility is different for the next job, returning to the leader")
         return None
     if successor.predecessorNumber > 1:
         logger.debug("The next job has multiple predecessors; we must return to the leader.")
@@ -383,7 +383,7 @@ def workerScript(jobStore: AbstractJobStore, config: Config, jobName: str, jobSt
 
                 # Create a fileStore object for the job
                 fileStore = AbstractFileStore.createFileStore(jobStore, jobDesc, localWorkerTempDir, blockFn,
-                                                              caching=not config.disableCaching)
+                                                              caching=config.caching)
                 with job._executor(stats=statsDict if config.stats else None,
                                    fileStore=fileStore):
                     with deferredFunctionManager.open() as defer:
@@ -468,7 +468,7 @@ def workerScript(jobStore: AbstractJobStore, config: Config, jobName: str, jobSt
             # Build a fileStore to update the job and commit the replacement.
             # TODO: can we have a commit operation without an entire FileStore???
             fileStore = AbstractFileStore.createFileStore(jobStore, jobDesc, localWorkerTempDir, blockFn,
-                                                          caching=not config.disableCaching)
+                                                          caching=config.caching)
 
             # Update blockFn to wait for that commit operation.
             blockFn = fileStore.waitForCommit
